@@ -1,7 +1,7 @@
 package parent;
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.222';
+$VERSION = '0.227';
 
 sub import {
     my $class = shift;
@@ -23,9 +23,7 @@ sub import {
 
     {
         no strict 'refs';
-        # This is more efficient than push for the new MRO
-        # at least until the new MRO is fixed
-        @{"$inheritor\::ISA"} = (@{"$inheritor\::ISA"} , @_);
+        push @{"$inheritor\::ISA"}, @_;
     };
 };
 
@@ -33,6 +31,8 @@ sub import {
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 parent - Establish an ISA relationship with base classes at compile time
@@ -102,7 +102,7 @@ either C<.pm> or C<.pmc>), use the following code:
 
 Attempting to inherit from yourself generates a warning.
 
-    use Foo;
+    package Foo;
     use parent 'Foo';
 
 =back
@@ -120,13 +120,13 @@ L<base>
 
 =head1 AUTHORS AND CONTRIBUTORS
 
-Rafal Garcia-Suarez, Bart Lateur, Max Maischein, Anno Siegel, Michael Schwern
+Rafaël Garcia-Suarez, Bart Lateur, Max Maischein, Anno Siegel, Michael Schwern
 
 =head1 MAINTAINER
 
 Max Maischein C< corion@cpan.org >
 
-Copyright (c) 2007 Max Maischein C<< <corion@cpan.org> >>
+Copyright (c) 2007-10 Max Maischein C<< <corion@cpan.org> >>
 Based on the idea of C<base.pm>, which was introduced with Perl 5.004_04.
 
 =head1 LICENSE
